decide_recovery

Function decide_recovery 

pub(super) fn decide_recovery<'a>(
    row: &CreditRegistration,
    facts: &RowFacts,
    answer: Option<&'a EnrolmentAnswer>,
) -> Decision<'a>
Settles an uncertain row as duplicate if the lookup found the attainment it would have created, and otherwise leaves it uncertain.